fieldset.content div input,
fieldset.other div input {
	width: 586px;
	padding: 10px;
	font-size: 14px;
}
div.form-row.field-parent,
div.form-row.field-status{
	border-bottom: 0 none;
	width: 390px;
	margin: 0;
	padding: 10px 10px;
	display: inline-block;
}
div.form-row.field-title{
	border-top: 1px solid #EEE;
}
	div.form-row.field-parent select,
	div.form-row.field-status select{
		width: 50%;
	}
div.form-row.field-layout,
div.form-row.field-order,
div.form-row.field-password,
div.form-row.field-slug{
	border-bottom: 0 none;
	width: 45%;
	margin: 0;
	padding: 10px 10px;
	display: inline-block;
	vertical-align: top;
}
	div.form-row.field-layout select{
		width: 100%;
		margin-top: 1em;
	}

fieldset.collapsed .form-row{
	display: none;
}
