{% extends 'ccpages/base.html' %}

{% load ccpages_tags %}


{% block title %}{{page.title}} &ndash; {% endblock %}

{% block breadcrumbs %}
	{% ccpages_nav_breadcrumbs page %}
{% endblock %}

{% block nav_local %}
	{% ccpages_nav_local page %}
{% endblock %}

{% block content %}
<h1>Password Required</h1>

<p>
	{{page.title}} requires a password
</p>

<form method="post">
	{% csrf_token %}

	{% with field=form.password %}
		<fieldset class="required {% if field.errors %} error {% endif %}">
			<label for="id_{{field.html_name}}">
				{{field.label|title}}
				{% for error in field.errors %}
					{% if forloop.first %} &ndash; {% endif %}
					{{error|lower}}
					{% if not forloop.last %}, {% endif %}
				{% endfor %}
			</label>
			{{field}}
		</fieldset>
	{% endwith %}
	
	<button type="submit">Next</button>

</form>
{% endblock %}
